@@ -1,19 +1,21 @@
 use {
     crate::{state::*, errors::*},
     anchor_lang::{prelude::*},
-    cardinal_token_manager::{state::TokenManager},
-    cardinal_payment_manager::{state::PaymentManager},
+    cardinal_token_manager::{state::{TokenManager, TokenManagerState}},
 };
 
 #[derive(Accounts)]
 #[instruction(bump: u8, payment_amount: u64)]
 pub struct InitCtx<'info> {
-    #[account(constraint = token_manager.payment_manager != None && token_manager.payment_manager.unwrap() == payment_manager.key() @ ErrorCode::InvalidPaymentManager)]
+    #[account(constraint =
+        token_manager.payment_mint != None
+        && token_manager.state == TokenManagerState::Initialized as u8
+        @ ErrorCode::InvalidTokenManager
+    )]
     token_manager: Box<Account<'info, TokenManager>>,
-    payment_manager: Box<Account<'info, PaymentManager>>,
 
     #[account(
-        init,
+        init_if_needed,
         payer = payer,
         space = PAID_CLAIM_APPROVER_SIZE,
         seeds = [PAID_CLAIM_APPROVER_SEED.as_bytes(), token_manager.key().as_ref()], bump = bump,
